pub fn validate_row<S, T>(value: &T) -> Result<(), VldSqlxError>Expand description
Validate a row loaded from the database against schema S.
Useful to enforce invariants on data that may have been inserted by other systems or before validation was in place.