pub struct VldError {
pub issues: Vec<ValidationIssue>,
}Expand description
Collection of validation errors.
Errors are accumulated (not short-circuited), so all issues are reported at once.
Fields
issues: Vec<ValidationIssue>Implementations
Sourceimpl VldError
impl VldError
Sourcepub fn single(code: IssueCode, message: impl Into<String>) -> VldError
pub fn single(code: IssueCode, message: impl Into<String>) -> VldError
Create an error with a single issue (no received value).
Sourcepub fn single_with_value(
code: IssueCode,
message: impl Into<String>,
received: &Value,
) -> VldError
pub fn single_with_value( code: IssueCode, message: impl Into<String>, received: &Value, ) -> VldError
Create an error with a single issue and the received value.
Sourcepub fn with_prefix(self, segment: PathSegment) -> VldError
pub fn with_prefix(self, segment: PathSegment) -> VldError
Prepend a path segment to all issues (used for nested objects/arrays).
Sourceimpl VldError
impl VldError
Sourcepub fn issue(&mut self, code: IssueCode) -> IssueBuilder<'_>
pub fn issue(&mut self, code: IssueCode) -> IssueBuilder<'_>
Start building a new issue with the fluent API.
Call .message(...), .path_field(...), .received(...) etc., then
.finish() to push the issue.
Example
use vld::prelude::*;
let mut errors = VldError::new();
errors
.issue(IssueCode::Custom { code: "my_check".into() })
.message("something went wrong")
.path_field("field_name")
.finish();Trait Implementations
Sourceimpl Error for VldError
impl Error for VldError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<VldError> for VldSqlxError
impl From<VldError> for VldSqlxError
Sourceimpl Serialize for VldError
impl Serialize for VldError
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more