pub struct VldInt<S> { /* private fields */ }Expand description
A validated integer column type.
Wraps an i64 and ensures it passes the vld schema S on construction.
Implements SQLx Type, Encode, Decode for any database where i64 does.
The schema must have a field named value.
Example
use vld::prelude::*;
vld::schema! {
#[derive(Debug)]
pub struct AgeField {
pub value: i64 => vld::number().int().min(0).max(150),
}
}
let age = vld_sqlx::VldInt::<AgeField>::new(25).unwrap();
assert_eq!(*age, 25);
assert!(vld_sqlx::VldInt::<AgeField>::new(-1).is_err());Implementations