pub struct ZDiscriminatedUnion { /* private fields */ }Expand description
Discriminated union: chooses a schema based on a discriminator field value.
More efficient than a regular union because it looks up the correct variant by the discriminator field value instead of trying each schema in order.
Created via vld::discriminated_union().
Example
ⓘ
let schema = vld::discriminated_union("type")
.variant("dog", vld::object().field("type", vld::literal("dog")).field("bark", vld::boolean()))
.variant("cat", vld::object().field("type", vld::literal("cat")).field("lives", vld::number().int()));Implementations
Sourceimpl ZDiscriminatedUnion
impl ZDiscriminatedUnion
pub fn new(discriminator: impl Into<String>) -> ZDiscriminatedUnion
Sourcepub fn variant<S>(
self,
value: impl Into<Value>,
schema: S,
) -> ZDiscriminatedUnionwhere
S: DynSchema + 'static,
pub fn variant<S>(
self,
value: impl Into<Value>,
schema: S,
) -> ZDiscriminatedUnionwhere
S: DynSchema + 'static,
Add a variant: when the discriminator field equals value, use schema.
Sourcepub fn variant_str<S>(self, value: &str, schema: S) -> ZDiscriminatedUnionwhere
S: DynSchema + 'static,
pub fn variant_str<S>(self, value: &str, schema: S) -> ZDiscriminatedUnionwhere
S: DynSchema + 'static,
Add a string variant (convenience).