pub struct ZInt { /* private fields */ }Expand description
Schema for integer validation (i64). Created via vld::number().int().
Implementations
Sourceimpl ZInt
impl ZInt
Sourcepub fn type_error(self, msg: impl Into<String>) -> ZInt
pub fn type_error(self, msg: impl Into<String>) -> ZInt
Set a custom error message for type mismatch (non-number input).
Sourcepub fn int_error(self, msg: impl Into<String>) -> ZInt
pub fn int_error(self, msg: impl Into<String>) -> ZInt
Set a custom error message for when the number is not an integer.
Example
use vld::prelude::*;
let schema = vld::number().int().int_error("Whole numbers only!");
let err = schema.parse("3.5").unwrap_err();
assert!(err.issues[0].message.contains("Whole numbers only!"));Sourcepub fn with_messages<F>(self, f: F) -> ZInt
pub fn with_messages<F>(self, f: F) -> ZInt
Override error messages in bulk by check key.
Same keys as ZNumber::with_messages, plus "not_int" for the
integer check itself.
Sourcepub fn non_negative(self) -> ZInt
pub fn non_negative(self) -> ZInt
Must be non-negative (>= 0).
Sourcepub fn non_positive(self) -> ZInt
pub fn non_positive(self) -> ZInt
Must be non-positive (<= 0).
Sourcepub fn multiple_of(self, val: i64) -> ZInt
pub fn multiple_of(self, val: i64) -> ZInt
Must be a multiple of the given value.